﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2013 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Collections.Generic;
using System.Drawing;
using HeuristicLab.Analysis;
using HeuristicLab.Common;
using HeuristicLab.Core;

namespace HeuristicLab.DataPreprocessing {

  [Item("ScatterPlot", "Represents a scatter plot.")]
  public class ScatterPlotContent : Item, IViewChartShortcut {
    public static new Image StaticItemImage {
      get { return HeuristicLab.Common.Resources.VSImageLibrary.Performance; }
    }

    public string SelectedXVariable { get; set; }
    public string SelectedYVariable { get; set; }

    public IPreprocessingContext Context {
      get;
      private set;
    }
    public ITransactionalPreprocessingData PreprocessingData {
      get { return Context.Data; }
    }

    public ScatterPlotContent(IPreprocessingContext context)
      : base() {
      this.Context = context;
    }

    public ScatterPlotContent(ScatterPlotContent content, Cloner cloner)
      : base(content, cloner) {
      this.Context = content.Context;
      this.SelectedXVariable = content.SelectedXVariable;
      this.SelectedYVariable = content.SelectedYVariable;
    }
    public override IDeepCloneable Clone(Cloner cloner) {
      return new ScatterPlotContent(this, cloner);
    }

    public DataRow CreateDataRow(string variableName, DataRowVisualProperties.DataRowChartType chartType) {
      int columnIndex = PreprocessingData.GetColumnIndex(variableName);
      IList<double> values = PreprocessingData.GetValues<double>(columnIndex);
      DataRow row = new DataRow(variableName, "", values);
      row.VisualProperties.ChartType = chartType;
      return row;
    }

    public IEnumerable<string> GetVariableNames() {
      List<string> doubleVariableNames = new List<string>();

      //only return variable names from type double
      foreach (string variableName in PreprocessingData.VariableNames) {
        if (PreprocessingData.IsType<double>(PreprocessingData.GetColumnIndex(variableName)))
          doubleVariableNames.Add(variableName);
      }

      return doubleVariableNames;
    }

    public ScatterPlot CreateScatterPlot(string variableNameX, string variableNameY) {
      ScatterPlot scatterPlot = new ScatterPlot();

      int xColumnIndex = PreprocessingData.GetColumnIndex(variableNameX);
      int yColumnIndex = PreprocessingData.GetColumnIndex(variableNameY);

      IList<double> xValues = PreprocessingData.GetValues<double>(xColumnIndex);
      IList<double> yValues = PreprocessingData.GetValues<double>(yColumnIndex);

      List<Point2D<double>> points = new List<Point2D<double>>();

      for (int i = 0; i < xValues.Count; i++) {
        Point2D<double> point = new Point2D<double>(xValues[i], yValues[i]);
        points.Add(point);
      }

      ScatterPlotDataRow scdr = new ScatterPlotDataRow(variableNameX + " - " + variableNameY, "", points);
      scatterPlot.Rows.Add(scdr);
      return scatterPlot;
    }

  }
}
